@@ -10,6 +10,8 @@ using namespace Rcpp;
 #ifndef MN
 #define MN
 
+#define SWAP(x,y,tmp) { tmp=x; x=y; y=tmp; }
+
 mat operator+(colvec &,mat &);
 colvec operator^(colvec ,const int );
 colvec operator-(colvec &,colvec &);
@@ -17,15 +19,18 @@ double operator*(vec ,vec );
 colvec operator+(colvec &,colvec &);
 colvec operator^(const char ,const colvec );
 vec loga(vec &);
-bool my_compare(const pair<string,int>& ,const pair<string,int>&);
+bool my_compare1(const pair<string,int>& ,const pair<string,int>&);
+bool my_compare_order(const pair<double,int>& ,const pair<double,int>&);
+bool descending(const double& a,const double& b);
+bool cor_vecs(const pair<double,double>& a,const pair<double,double>& b);
+bool s_indx_asc(const pair<int,double>& a,const pair<int,double>& b);
+bool s_indx_des(const pair<int,double>& a,const pair<int,double>& b);
 mat design_matrix(CharacterVector);
 vector<int> which_isFactor(DataFrame);
 vec regression_only(mat, colvec);
 long double regression_only_col(colvec , colvec );
-unsigned int generatekey2(const string & ,unsigned  int );
-static const size_t InitialFNV = 2166136261U;
-static const size_t FNVMultiple = 16777619;
-size_t generatekey1(const string &);
 double digamma(double);
 double trigamma(double);
+void i4mat_floyd ( int n, vector<double> &a );
+
 #endif
